==> walkers-fabric-1.20.1-4.2-sources.jar: tocraft/walkers/skills/impl/MobEffectSkill.java <==
package tocraft.walkers.skills.impl;

import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1058;
import net.minecraft.class_1293;
import net.minecraft.class_1309;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_7923;
import org.jetbrains.annotations.Nullable;
import tocraft.walkers.Walkers;
import tocraft.walkers.skills.ShapeSkill;

import java.util.Objects;
import java.util.Optional;

public class MobEffectSkill<E extends class_1309> extends ShapeSkill<E> {
    public static final class_2960 ID = Walkers.id("mob_effect");
    public static final Codec<class_1293> MOB_EFFECT_INSTANCE_CODEC = RecordCodecBuilder.create((instance) -> instance.group(
            class_2960.field_25139.fieldOf("id").forGetter(o -> class_7923.field_41174.method_10221(o.method_5579())),
            Codec.INT.fieldOf("duration").forGetter(class_1293::method_5584),
            Codec.INT.fieldOf("amplifier").forGetter(class_1293::method_5578),
            Codec.BOOL.optionalFieldOf("ambient", false).forGetter(class_1293::method_5591),
            Codec.BOOL.optionalFieldOf("show_particles", true).forGetter(class_1293::method_5581),
            Codec.BOOL.optionalFieldOf("show_icon").forGetter(o -> Optional.of(o.method_5592()))
    ).apply(instance, instance.stable((id, duration, amplifier, ambient, show_particles, show_icon) -> new class_1293(Objects.requireNonNull(class_7923.field_41174.method_10223(id)), duration, amplifier, ambient, show_particles, show_icon.orElse(show_particles)))));
    public static final Codec<MobEffectSkill<?>> CODEC = RecordCodecBuilder.create((instance) -> instance.group(
            MOB_EFFECT_INSTANCE_CODEC.fieldOf("mob_effect").forGetter(o -> o.mobEffectInstance),
            Codec.BOOL.optionalFieldOf("show_in_inventory", true).forGetter(o -> o.showInInventory),
            Codec.BOOL.optionalFieldOf("apply_to_self", true).forGetter(o -> o.applyToSelf),
            Codec.INT.optionalFieldOf("apply_to_nearby", -1).forGetter(o -> o.applyToNearby),
            Codec.INT.optionalFieldOf("max_distance_for_entities", -1).forGetter(o -> o.maxDistanceForEntities),
            Codec.INT.optionalFieldOf("amount_of_entities_to_apply_to", -1).forGetter(o -> o.amountOfEntitiesToApplyTo)
    ).apply(instance, instance.stable(MobEffectSkill::new)));

    public final class_1293 mobEffectInstance;
    public final boolean showInInventory;
    public final boolean applyToSelf;
    public final int applyToNearby;
    public final int maxDistanceForEntities;
    public final int amountOfEntitiesToApplyTo;

    public MobEffectSkill(class_1293 mobEffectInstance) {
        this(mobEffectInstance, false);
    }

    public MobEffectSkill(class_1293 mobEffectInstance, boolean showInInventory) {
        this(mobEffectInstance, showInInventory, true, -1, -1, -1);
    }

    /**
     * @param mobEffectInstance         the effect to apply
     * @param showInInventory           should the effect be displayed to the player? Only for self
     * @param applyToSelf               should the player get it?
     * @param applyToNearby             should nearby entities get it? negative - no, 0 - player only, 1 - mobs only, 2 - players and mobs
     * @param maxDistanceForEntities    only used when applyToNearby is true
     * @param amountOfEntitiesToApplyTo only used when applyToNearby is true
     */
    public MobEffectSkill(class_1293 mobEffectInstance, boolean showInInventory, boolean applyToSelf, int applyToNearby, int maxDistanceForEntities, int amountOfEntitiesToApplyTo) {
        this.showInInventory = showInInventory;
        this.mobEffectInstance = mobEffectInstance;
        this.applyToSelf = applyToSelf;
        this.applyToNearby = applyToNearby;
        this.maxDistanceForEntities = maxDistanceForEntities;
        this.amountOfEntitiesToApplyTo = amountOfEntitiesToApplyTo;
    }

    @Override
    public class_2960 getId() {
        return ID;
    }

    @Override
    public Codec<? extends ShapeSkill<?>> codec() {
        return CODEC;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public boolean iconMightDiffer() {
        return true;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public @Nullable class_1058 getIcon() {
        return class_310.method_1551().method_18505().method_18663(mobEffectInstance.method_5579());
    }
}

==> walkers-fabric-1.20.2-4.4.1-sources.jar: tocraft/walkers/skills/impl/MobEffectSkill.java <==
package tocraft.walkers.skills.impl;

import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1058;
import net.minecraft.class_1293;
import net.minecraft.class_1309;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_7923;
import org.jetbrains.annotations.Nullable;
import tocraft.walkers.Walkers;
import tocraft.walkers.skills.ShapeSkill;

import java.util.Optional;

public class MobEffectSkill<E extends class_1309> extends ShapeSkill<E> {
    public static final class_2960 ID = Walkers.id("mob_effect");
    @SuppressWarnings("DataFlowIssue")
    public static final Codec<class_1293> MOB_EFFECT_INSTANCE_CODEC = RecordCodecBuilder.create((instance) -> instance.group(
            class_2960.field_25139.fieldOf("id").forGetter(o -> class_7923.field_41174.method_10221(o.method_5579())),
            Codec.INT.fieldOf("duration").forGetter(class_1293::method_5584),
            Codec.INT.fieldOf("amplifier").forGetter(class_1293::method_5578),
            Codec.BOOL.optionalFieldOf("ambient", false).forGetter(class_1293::method_5591),
            Codec.BOOL.optionalFieldOf("show_particles", true).forGetter(class_1293::method_5581),
            Codec.BOOL.optionalFieldOf("show_icon").forGetter(o -> Optional.of(o.method_5592()))
    ).apply(instance, instance.stable((id, duration, amplifier, ambient, show_particles, show_icon) -> new class_1293(class_7923.field_41174.method_10223(id), duration, amplifier, ambient, show_particles, show_icon.orElse(show_particles)))));
    public static final Codec<MobEffectSkill<?>> CODEC = RecordCodecBuilder.create((instance) -> instance.group(
            MOB_EFFECT_INSTANCE_CODEC.fieldOf("mob_effect").forGetter(o -> o.mobEffectInstance),
            Codec.BOOL.optionalFieldOf("show_in_inventory", true).forGetter(o -> o.showInInventory),
            Codec.BOOL.optionalFieldOf("apply_to_self", true).forGetter(o -> o.applyToSelf),
            Codec.INT.optionalFieldOf("apply_to_nearby", -1).forGetter(o -> o.applyToNearby),
            Codec.INT.optionalFieldOf("max_distance_for_entities", -1).forGetter(o -> o.maxDistanceForEntities),
            Codec.INT.optionalFieldOf("amount_of_entities_to_apply_to", -1).forGetter(o -> o.amountOfEntitiesToApplyTo)
    ).apply(instance, instance.stable(MobEffectSkill::new)));

    public final class_1293 mobEffectInstance;
    public final boolean showInInventory;
    public final boolean applyToSelf;
    public final int applyToNearby;
    public final int maxDistanceForEntities;
    public final int amountOfEntitiesToApplyTo;

    public MobEffectSkill(class_1293 mobEffectInstance) {
        this(mobEffectInstance, false);
    }

    public MobEffectSkill(class_1293 mobEffectInstance, boolean showInInventory) {
        this(mobEffectInstance, showInInventory, true, -1, -1, -1);
    }

    /**
     * @param mobEffectInstance         the effect to apply
     * @param showInInventory           should the effect be displayed to the player? Only for self
     * @param applyToSelf               should the player get it?
     * @param applyToNearby             should nearby entities get it? negative - no, 0 - player only, 1 - mobs only, 2 - players and mobs
     * @param maxDistanceForEntities    only used when applyToNearby is true
     * @param amountOfEntitiesToApplyTo only used when applyToNearby is true
     */
    public MobEffectSkill(class_1293 mobEffectInstance, boolean showInInventory, boolean applyToSelf, int applyToNearby, int maxDistanceForEntities, int amountOfEntitiesToApplyTo) {
        this.showInInventory = showInInventory;
        this.mobEffectInstance = mobEffectInstance;
        this.applyToSelf = applyToSelf;
        this.applyToNearby = applyToNearby;
        this.maxDistanceForEntities = maxDistanceForEntities;
        this.amountOfEntitiesToApplyTo = amountOfEntitiesToApplyTo;
    }

    @Override
    public class_2960 getId() {
        return ID;
    }

    @Override
    public Codec<? extends ShapeSkill<?>> codec() {
        return CODEC;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public boolean iconMightDiffer() {
        return true;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public @Nullable class_1058 getIcon() {
        return class_310.method_1551().method_18505().method_18663(mobEffectInstance.method_5579());
    }
}
